@@ -34,7 +34,7 @@ def start():
 
     ProcessManager(
         "Start Chrome",
-        [os.environ["COMSPEC"], "/C", 'start chrome "http://127.0.0.1/app/"'],
+        [os.environ["COMSPEC"], "/C", "start chrome http://127.0.0.1/app/"],
     ).start()
 
     try:
